rest\_witchcraft package
========================

.. automodule:: rest_witchcraft
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   rest_witchcraft.field_mapping
   rest_witchcraft.fields
   rest_witchcraft.filters
   rest_witchcraft.generics
   rest_witchcraft.mixins
   rest_witchcraft.routers
   rest_witchcraft.serializers
   rest_witchcraft.utils
   rest_witchcraft.viewsets
